# OCF Template Repository
Template Repository for OCF Projects

## Usage

Do the following to customize the repo to the project:

- Replace `src` with name of the library/project
- Update `setup.py` with the proper info
- Change `commit` to `True` in `.bumpversion.cfg` if you want the minor version
  to increment on every commit.
- Add PyPi access token to release to PyPi
- Update name of folder in the test workflow
